@@ -51,6 +51,7 @@ extern int main_debug;
 #pragma GCC diagnostic ignored "-Wswitch-default"
 /* YYSTYPE and YYLTYPE is defined by the lexer */
 #include "cfg-lexer.h"
+#include "cfg-path.h"
 #include "afinter.h"
 #include "type-hinting.h"
 #include "filter/filter-expr-parser.h"
@@ -60,7 +61,9 @@ extern int main_debug;
 #include "logmatcher.h"
 #include "logthrdest/logthrdestdrv.h"
 #include "logthrsource/logthrsourcedrv.h"
+#include "logthrsource/logthrfetcherdrv.h"
 #include "str-utils.h"
+#include <sys/stat.h>
 
 /* uses struct declarations instead of the typedefs to avoid having to
  * include logreader/logwriter/driver.h, which defines the typedefs.  This
@@ -85,7 +88,7 @@ extern struct _HostResolveOptions *last_host_resolve_options;
 extern struct _StatsOptions *last_stats_options;
 
 
-#line 89 "lib/cfg-grammar.h" /* yacc.c:1909  */
+#line 92 "lib/cfg-grammar.h" /* yacc.c:1909  */
 
 /* Token type.  */
 #ifndef YYTOKENTYPE
@@ -238,7 +241,8 @@ extern struct _StatsOptions *last_stats_options;
     KW_ADD_PREFIX = 10509,
     KW_REPLACE_PREFIX = 10510,
     KW_ON_ERROR = 10511,
-    KW_RETRIES = 10512
+    KW_RETRIES = 10512,
+    KW_FETCH_NO_DATA_DELAY = 10513
   };
 #endif
 /* Tokens.  */
@@ -389,6 +393,7 @@ extern struct _StatsOptions *last_stats_options;
 #define KW_REPLACE_PREFIX 10510
 #define KW_ON_ERROR 10511
 #define KW_RETRIES 10512
+#define KW_FETCH_NO_DATA_DELAY 10513
 
 /* Value type.  */
 
